ServerStorageVersion

Struct ServerStorageVersion 

pub struct ServerStorageVersion {
    pub api_server_id: String,
    pub decodable_versions: Vec<String>,
    pub encoding_version: String,
    pub served_versions: Option<Vec<String>>,
}
An API server instance reports the version it can decode and the version it encodes objects to when persisting objects in the backend.

Fields

api_server_id: String

apiServerID is the ID of the reporting API server.

decodable_versions: Vec<String>

decodableVersions are the encoding versions the API server can handle to decode. The API server can decode objects encoded in these versions. The encodingVersion must be included in the decodableVersions.

encoding_version: String

encodingVersion the API server encodes the object to when persisting it in the backend (e.g., etcd).

served_versions: Option<Vec<String>>

servedVersions lists all versions the API server can serve. DecodableVersions must include all ServedVersions.